==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/ParametersFromSourceFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParametersFromSourceFluentImpl<A extends ParametersFromSourceFluent<A>> extends BaseFluent<A> implements ParametersFromSourceFluent<A>{
  public ParametersFromSourceFluentImpl() {
  }
  public ParametersFromSourceFluentImpl(ParametersFromSource instance) {
    this.withSecretKeyRef(instance.getSecretKeyRef()); 
  }
  private SecretKeyReferenceBuilder secretKeyRef;
  
  /**
   * This method has been deprecated, please use method buildSecretKeyRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeyReference getSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public SecretKeyReference buildSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public A withSecretKeyRef(SecretKeyReference secretKeyRef) {
    _visitables.get("secretKeyRef").remove(this.secretKeyRef);
    if (secretKeyRef!=null){ this.secretKeyRef= new SecretKeyReferenceBuilder(secretKeyRef); _visitables.get("secretKeyRef").add(this.secretKeyRef);} else { this.secretKeyRef = null; _visitables.get("secretKeyRef").remove(this.secretKeyRef); } return (A) this;
  }
  public Boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public A withNewSecretKeyRef(String key,String name) {
    return (A)withSecretKeyRef(new SecretKeyReference(key, name));
  }
  public ParametersFromSourceFluent.SecretKeyRefNested<A> withNewSecretKeyRef() {
    return new ParametersFromSourceFluentImpl.SecretKeyRefNestedImpl();
  }
  public ParametersFromSourceFluent.SecretKeyRefNested<A> withNewSecretKeyRefLike(SecretKeyReference item) {
    return new ParametersFromSourceFluentImpl.SecretKeyRefNestedImpl(item);
  }
  public ParametersFromSourceFluent.SecretKeyRefNested<A> editSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef());
  }
  public ParametersFromSourceFluent.SecretKeyRefNested<A> editOrNewSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): new SecretKeyReferenceBuilder().build());
  }
  public ParametersFromSourceFluent.SecretKeyRefNested<A> editOrNewSecretKeyRefLike(SecretKeyReference item) {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ParametersFromSourceFluentImpl that = (ParametersFromSourceFluentImpl) o;
    if (secretKeyRef != null ? !secretKeyRef.equals(that.secretKeyRef) :that.secretKeyRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretKeyRefNestedImpl<N> extends SecretKeyReferenceFluentImpl<ParametersFromSourceFluent.SecretKeyRefNested<N>> implements ParametersFromSourceFluent.SecretKeyRefNested<N>,Nested<N>{
    SecretKeyRefNestedImpl(SecretKeyReference item) {
      this.builder = new SecretKeyReferenceBuilder(this, item);
    }
    SecretKeyRefNestedImpl() {
      this.builder = new SecretKeyReferenceBuilder(this);
    }
    SecretKeyReferenceBuilder builder;
    public N and() {
      return (N) ParametersFromSourceFluentImpl.this.withSecretKeyRef(builder.build());
    }
    public N endSecretKeyRef() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ParametersFromSourceFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParametersFromSourceFluentImpl<A extends ParametersFromSourceFluent<A>> extends BaseFluent<A> implements ParametersFromSourceFluent<A>{
  public ParametersFromSourceFluentImpl() {
  }
  public ParametersFromSourceFluentImpl(ParametersFromSource instance) {
    if (instance != null) {
      this.withSecretKeyRef(instance.getSecretKeyRef());
    }
  }
  private SecretKeyReferenceBuilder secretKeyRef;
  
  /**
   * This method has been deprecated, please use method buildSecretKeyRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeyReference getSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public SecretKeyReference buildSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  public A withSecretKeyRef(SecretKeyReference secretKeyRef) {
    _visitables.get("secretKeyRef").remove(this.secretKeyRef);
    if (secretKeyRef!=null){ this.secretKeyRef= new SecretKeyReferenceBuilder(secretKeyRef); _visitables.get("secretKeyRef").add(this.secretKeyRef);} else { this.secretKeyRef = null; _visitables.get("secretKeyRef").remove(this.secretKeyRef); } return (A) this;
  }
  public Boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public A withNewSecretKeyRef(String key,String name) {
    return (A)withSecretKeyRef(new SecretKeyReference(key, name));
  }
  public ParametersFromSourceFluentImpl.SecretKeyRefNested<A> withNewSecretKeyRef() {
    return new ParametersFromSourceFluentImpl.SecretKeyRefNestedImpl();
  }
  public ParametersFromSourceFluentImpl.SecretKeyRefNested<A> withNewSecretKeyRefLike(SecretKeyReference item) {
    return new ParametersFromSourceFluentImpl.SecretKeyRefNestedImpl(item);
  }
  public ParametersFromSourceFluentImpl.SecretKeyRefNested<A> editSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef());
  }
  public ParametersFromSourceFluentImpl.SecretKeyRefNested<A> editOrNewSecretKeyRef() {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): new SecretKeyReferenceBuilder().build());
  }
  public ParametersFromSourceFluentImpl.SecretKeyRefNested<A> editOrNewSecretKeyRefLike(SecretKeyReference item) {
    return withNewSecretKeyRefLike(getSecretKeyRef() != null ? getSecretKeyRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParametersFromSourceFluentImpl that = (ParametersFromSourceFluentImpl) o;
    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretKeyRefNestedImpl<N> extends SecretKeyReferenceFluentImpl<ParametersFromSourceFluentImpl.SecretKeyRefNested<N>> implements ParametersFromSourceFluentImpl.SecretKeyRefNested<N>,Nested<N>{
    SecretKeyRefNestedImpl(SecretKeyReference item) {
      this.builder = new SecretKeyReferenceBuilder(this, item);
    }
    SecretKeyRefNestedImpl() {
      this.builder = new SecretKeyReferenceBuilder(this);
    }
    SecretKeyReferenceBuilder builder;
    public N and() {
      return (N) ParametersFromSourceFluentImpl.this.withSecretKeyRef(builder.build());
    }
    public N endSecretKeyRef() {
      return and();
    }
    
  }
  
}
